@@ -6,9 +6,8 @@ test -z "$srcdir" && srcdir=.
 
 PKG_NAME="sound-juicer"
 
-(test -f $srcdir/configure.in) || {
-    echo -n "**Error**: Directory "\`$srcdir\'" does not look like the"
-    echo " top-level $PKG_NAME directory"
+(test -f $srcdir/src/sound-juicer.h) || {
+    echo "**Error**: Directory "\`$srcdir\'" does not look like the top-level $PKG_NAME directory"
     exit 1
 }
 
@@ -17,4 +16,4 @@ which gnome-autogen.sh || {
 	exit 1
 }
 
-REQUIRED_AUTOMAKE_VERSION=1.6 USE_GNOME2_MACROS=1 . gnome-autogen.sh
+REQUIRED_AUTOMAKE_VERSION=1.9 USE_GNOME2_MACROS=1 . gnome-autogen.sh
